/*
 * Copyright © 2015 Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Alexander Larsson <alexl@redhat.com>
 */

#if !defined(__KAIMING_H_INSIDE__) && !defined(KAIMING_COMPILATION)
#error "Only <kaiming.h> can be included directly."
#endif

#ifndef __KAIMING_BUNDLE_REF_H__
#define __KAIMING_BUNDLE_REF_H__

typedef struct _KaimingBundleRef KaimingBundleRef;

#include <gio/gio.h>
#include <kaiming-ref.h>

G_BEGIN_DECLS

#define KAIMING_TYPE_BUNDLE_REF kaiming_bundle_ref_get_type ()
#define KAIMING_BUNDLE_REF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), KAIMING_TYPE_BUNDLE_REF, KaimingBundleRef))
#define KAIMING_IS_BUNDLE_REF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KAIMING_TYPE_BUNDLE_REF))

KAIMING_EXTERN GType kaiming_bundle_ref_get_type (void);

struct _KaimingBundleRef
{
  KaimingRef parent;
};

typedef struct
{
  KaimingRefClass parent_class;
} KaimingBundleRefClass;

KAIMING_EXTERN KaimingBundleRef *kaiming_bundle_ref_new (GFile   *file,
                                                         GError **error);
KAIMING_EXTERN GFile           *kaiming_bundle_ref_get_file (KaimingBundleRef *self);
KAIMING_EXTERN GBytes          *kaiming_bundle_ref_get_metadata (KaimingBundleRef *self);
KAIMING_EXTERN GBytes          *kaiming_bundle_ref_get_appstream (KaimingBundleRef *self);
KAIMING_EXTERN GBytes          *kaiming_bundle_ref_get_icon (KaimingBundleRef *self,
                                                             int               size);
KAIMING_EXTERN char            *kaiming_bundle_ref_get_origin (KaimingBundleRef *self);
KAIMING_EXTERN guint64          kaiming_bundle_ref_get_installed_size (KaimingBundleRef *self);
KAIMING_EXTERN char            *kaiming_bundle_ref_get_runtime_repo_url (KaimingBundleRef *self);


#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
G_DEFINE_AUTOPTR_CLEANUP_FUNC (KaimingBundleRef, g_object_unref)
#endif

G_END_DECLS

#endif /* __KAIMING_BUNDLE_REF_H__ */
