/*
 * Copyright © 2015 Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Alexander Larsson <alexl@redhat.com>
 */

#if !defined(__KAIMING_H_INSIDE__) && !defined(KAIMING_COMPILATION)
#error "Only <kaiming.h> can be included directly."
#endif

#ifndef __KAIMING_INSTALLED_REF_H__
#define __KAIMING_INSTALLED_REF_H__

typedef struct _KaimingInstalledRef KaimingInstalledRef;

#include <gio/gio.h>
#include <kaiming-ref.h>

G_BEGIN_DECLS

#define KAIMING_TYPE_INSTALLED_REF kaiming_installed_ref_get_type ()
#define KAIMING_INSTALLED_REF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), KAIMING_TYPE_INSTALLED_REF, KaimingInstalledRef))
#define KAIMING_IS_INSTALLED_REF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KAIMING_TYPE_INSTALLED_REF))

KAIMING_EXTERN GType kaiming_installed_ref_get_type (void);

struct _KaimingInstalledRef
{
  KaimingRef parent;
};

typedef struct
{
  KaimingRefClass parent_class;
} KaimingInstalledRefClass;

#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
G_DEFINE_AUTOPTR_CLEANUP_FUNC (KaimingInstalledRef, g_object_unref)
#endif

KAIMING_EXTERN const char  *kaiming_installed_ref_get_origin (KaimingInstalledRef  * self);
KAIMING_EXTERN const char * const *kaiming_installed_ref_get_subpaths (KaimingInstalledRef *self);
KAIMING_EXTERN guint64      kaiming_installed_ref_get_installed_size (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_deploy_dir (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_latest_commit (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_appdata_name (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_appdata_summary (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_appdata_version (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_appdata_license (KaimingInstalledRef *self);
KAIMING_EXTERN const char  *kaiming_installed_ref_get_appdata_content_rating_type (KaimingInstalledRef *self);
KAIMING_EXTERN GHashTable  *kaiming_installed_ref_get_appdata_content_rating (KaimingInstalledRef *self);
KAIMING_EXTERN gboolean     kaiming_installed_ref_get_is_current (KaimingInstalledRef *self);
KAIMING_EXTERN GBytes      *kaiming_installed_ref_load_metadata (KaimingInstalledRef *self,
                                                                 GCancellable        *cancellable,
                                                                 GError             **error);
KAIMING_EXTERN GBytes      *kaiming_installed_ref_load_appdata (KaimingInstalledRef *self,
                                                                GCancellable        *cancellable,
                                                                GError             **error);
KAIMING_EXTERN const char * kaiming_installed_ref_get_eol (KaimingInstalledRef *self);
KAIMING_EXTERN const char * kaiming_installed_ref_get_eol_rebase (KaimingInstalledRef *self);

G_END_DECLS

#endif /* __KAIMING_INSTALLED_REF_H__ */
