/*
 * Copyright © 2015 Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Alexander Larsson <alexl@redhat.com>
 */

#if !defined(__KAIMING_H_INSIDE__) && !defined(KAIMING_COMPILATION)
#error "Only <kaiming.h> can be included directly."
#endif

#ifndef __KAIMING_REF_H__
#define __KAIMING_REF_H__

typedef struct _KaimingRef KaimingRef;

#include <glib-object.h>

G_BEGIN_DECLS

#define KAIMING_TYPE_REF kaiming_ref_get_type ()
#define KAIMING_REF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), KAIMING_TYPE_REF, KaimingRef))
#define KAIMING_IS_REF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KAIMING_TYPE_REF))

KAIMING_EXTERN GType kaiming_ref_get_type (void);

struct _KaimingRef
{
  GObject parent;
};

typedef struct
{
  GObjectClass parent_class;
} KaimingRefClass;


#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
G_DEFINE_AUTOPTR_CLEANUP_FUNC (KaimingRef, g_object_unref)
#endif

/**
 * KaimingRefKind:
 * @KAIMING_REF_KIND_APP: An application
 * @KAIMING_REF_KIND_RUNTIME: A runtime that applications can use.
 *
 * The kind of artifact that a KaimingRef refers to.
 */
typedef enum {
  KAIMING_REF_KIND_APP,
  KAIMING_REF_KIND_RUNTIME,
} KaimingRefKind;

KAIMING_EXTERN const char *  kaiming_ref_get_name (KaimingRef *self);
KAIMING_EXTERN const char *  kaiming_ref_get_arch (KaimingRef *self);
KAIMING_EXTERN const char *  kaiming_ref_get_branch (KaimingRef *self);
KAIMING_EXTERN const char *  kaiming_ref_get_commit (KaimingRef *self);
KAIMING_EXTERN KaimingRefKind kaiming_ref_get_kind (KaimingRef *self);
KAIMING_EXTERN char *        kaiming_ref_format_ref (KaimingRef *self);
KAIMING_EXTERN const char *   kaiming_ref_format_ref_cached (KaimingRef *self);
KAIMING_EXTERN KaimingRef *   kaiming_ref_parse (const char *ref,
                                                 GError    **error);
KAIMING_EXTERN const char *   kaiming_ref_get_collection_id (KaimingRef *self);

G_END_DECLS

#endif /* __KAIMING_REF_H__ */
