/*
 * Copyright © 2015 Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *       Alexander Larsson <alexl@redhat.com>
 */

#if !defined(__KAIMING_H_INSIDE__) && !defined(KAIMING_COMPILATION)
#error "Only <kaiming.h> can be included directly."
#endif

#ifndef __KAIMING_REMOTE_H__
#define __KAIMING_REMOTE_H__

/**
 * KaimingRemoteType:
 * @KAIMING_REMOTE_TYPE_STATIC: Statically configured remote
 * @KAIMING_REMOTE_TYPE_USB: Dynamically detected local pathname remote
 * @KAIMING_REMOTE_TYPE_LAN: Dynamically detected network remote
 *
 * Different types of @KaimingRemote.
 */
typedef enum {
  KAIMING_REMOTE_TYPE_STATIC,
  KAIMING_REMOTE_TYPE_USB,
  KAIMING_REMOTE_TYPE_LAN,
} KaimingRemoteType;

typedef struct _KaimingRemote KaimingRemote;

#include <gio/gio.h>
#include <kaiming-remote-ref.h>

G_BEGIN_DECLS

#define KAIMING_TYPE_REMOTE kaiming_remote_get_type ()
#define KAIMING_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), KAIMING_TYPE_REMOTE, KaimingRemote))
#define KAIMING_IS_REMOTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KAIMING_TYPE_REMOTE))

KAIMING_EXTERN GType kaiming_remote_get_type (void);

struct _KaimingRemote
{
  GObject parent;
};

typedef struct
{
  GObjectClass parent_class;
} KaimingRemoteClass;

#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
G_DEFINE_AUTOPTR_CLEANUP_FUNC (KaimingRemote, g_object_unref)
#endif

KAIMING_EXTERN KaimingRemote * kaiming_remote_new (const char    *name);
KAIMING_EXTERN KaimingRemote * kaiming_remote_new_from_file (const char *name,
                                                             GBytes     *data,
                                                             GError **error);

KAIMING_EXTERN const char *  kaiming_remote_get_name (KaimingRemote *self);
KAIMING_EXTERN GFile *       kaiming_remote_get_appstream_dir (KaimingRemote *self,
                                                               const char    *arch);
KAIMING_EXTERN GFile *       kaiming_remote_get_appstream_timestamp (KaimingRemote *self,
                                                                     const char    *arch);
KAIMING_EXTERN char *        kaiming_remote_get_url (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_url (KaimingRemote *self,
                                                     const char    *url);
KAIMING_EXTERN char *        kaiming_remote_get_collection_id (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_collection_id (KaimingRemote *self,
                                                               const char    *collection_id);
KAIMING_EXTERN char *        kaiming_remote_get_title (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_title (KaimingRemote *self,
                                                       const char    *title);
KAIMING_EXTERN char *        kaiming_remote_get_comment (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_comment (KaimingRemote *self,
                                                         const char    *comment);
KAIMING_EXTERN char *        kaiming_remote_get_description (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_description (KaimingRemote *self,
                                                             const char    *description);
KAIMING_EXTERN char *        kaiming_remote_get_homepage (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_homepage (KaimingRemote *self,
                                                          const char    *homepage);
KAIMING_EXTERN char *        kaiming_remote_get_icon (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_icon (KaimingRemote *self,
                                                      const char    *icon);
KAIMING_EXTERN char *        kaiming_remote_get_default_branch (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_default_branch (KaimingRemote *self,
                                                                const char    *default_branch);
KAIMING_EXTERN char *        kaiming_remote_get_main_ref (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_main_ref (KaimingRemote *self,
                                                          const char    *main_ref);
KAIMING_EXTERN gboolean      kaiming_remote_get_gpg_verify (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_gpg_verify (KaimingRemote *self,
                                                            gboolean       gpg_verify);
KAIMING_EXTERN void          kaiming_remote_set_gpg_key (KaimingRemote *self,
                                                         GBytes        *gpg_key);
KAIMING_EXTERN gboolean      kaiming_remote_get_noenumerate (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_noenumerate (KaimingRemote *self,
                                                             gboolean       noenumerate);
KAIMING_EXTERN gboolean      kaiming_remote_get_nodeps (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_nodeps (KaimingRemote *self,
                                                        gboolean       nodeps);
KAIMING_EXTERN gboolean      kaiming_remote_get_disabled (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_disabled (KaimingRemote *self,
                                                          gboolean       disabled);
KAIMING_EXTERN int           kaiming_remote_get_prio (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_prio (KaimingRemote *self,
                                                      int            prio);
KAIMING_EXTERN char *        kaiming_remote_get_filter (KaimingRemote *self);
KAIMING_EXTERN void          kaiming_remote_set_filter (KaimingRemote *self,
                                                        const char    *filter_path);

KAIMING_EXTERN KaimingRemoteType kaiming_remote_get_remote_type (KaimingRemote *self);

G_END_DECLS

#endif /* __KAIMING_REMOTE_H__ */
